@@ -19,7 +19,6 @@
 #
 
 from __future__ import unicode_literals
-import distutils.sysconfig
 
 CONF_FILENAME='/etc/dnf/dnf.conf' # :api
 CONF_AUTOMATIC_FILENAME='/etc/dnf/automatic.conf'
@@ -50,8 +49,8 @@ VERBOSE_LEVEL=6
 PREFIX=NAME.lower()
 PROGRAM_NAME=NAME.lower()  # Deprecated - no longer used, Argparser prints program name based on sys.argv
 PLUGINCONFPATH = '/etc/dnf/plugins'  # :api
-PLUGINPATH = '%s/dnf-plugins' % distutils.sysconfig.get_python_lib()
-VERSION='4.2.23'
+PLUGINPATH = '/usr/lib/python3.12/site-packages/dnf-plugins'
+VERSION='4.18.0'
 USER_AGENT = "dnf/%s" % VERSION
 
 BUGTRACKER_COMPONENT=NAME.lower()
